/*
 * BiZduinoRTC.h - BiZduino DS1388 RTC ライブラリ
 * JeeLabs RTCLib ライブラリを元に作成
 */

#ifndef BiZduinoRTC_h
#define BiZduinoRTC_h


// Simple general-purpose date/time class (no TZ / DST / leap second handling!)
class DateTime {
public:
    DateTime (uint32_t t = 0);
    DateTime (uint16_t year, uint8_t month, uint8_t day,
                uint8_t hour = 0, uint8_t min = 0, uint8_t sec = 0);
    DateTime (const char* date, const char* time);

    uint16_t year() const       { return 2000 + yOff; }
    uint8_t month() const       { return m; }
    uint8_t day() const         { return d; }
    uint8_t hour() const        { return hh; }
    uint8_t minute() const      { return mm; }
    uint8_t second() const      { return ss; }
    uint8_t dayOfWeek() const;

    // 32-bit times as seconds since 1/1/2000
    long get() const;

protected:
    uint8_t yOff, m, d, hh, mm, ss;
    uint16_t mSec;
};


class BiZduinoRTC {
protected:
    static uint8_t WDSeconds;
    static uint8_t WDTSeconds;
    static bool exists;         // 有効通信あり
    static uint16_t mSec;       // ミリ秒
    static uint8_t getEEPROMBank(uint16_t pos);

    // utility functions
    static uint8_t bcd2bin (uint8_t val) { return val - 6 * (val >> 4); }
    static uint8_t bin2bcd (uint8_t val) { return val + 6 * (val / 10); }

public:
    static void begin();
    static bool adjust(const DateTime& dt);
    static bool read(DateTime& dt);
    static bool chipPresent() { return exists; }
    static uint16_t milliSecond() { return mSec; }

    // EEPROM
    static bool writeEEPROM(uint16_t pos, uint8_t c);
    static uint8_t readEEPROM(uint16_t pos);
    static bool writeEEPROMPage(uint8_t page, uint8_t* data);
    static bool readEEPROMPage(uint8_t page, uint8_t* data);

};


// RTCインスタンス
extern BiZduinoRTC RTC;

#endif
