// RTCのEEPROMのPage書込/読込のサンプルスケッチ
// SW3ボタンを押す度にEEPROM全領域に同値を書き込んでシリアルモニタに表示する

#include <BiZduino.h>
#include <BiZduinoRTC.h>


BiZduinoLED3 LED3;  // LED3インスタンス
BiZduinoSW3 SW3;    // SW3インスタンス


void setup() {
  // シリアルモニタとの通信を開始
  Serial.begin(115200);
  RTC.begin();

  // EEPROM全領域表示
  readAll();
}

void loop() {
  static uint8_t writeValue = 0;

  // SW3が押された時か判定
  if (SW3.isClicked()) {

    // LED3点灯
    LED3.on();

    Serial.println("Write start");

    // EEPROM全領域書き込み
    writeAll(writeValue);

    // LED3消灯
    LED3.off();

    // EEPROM全領域表示
    readAll();

    writeValue++;
  }

  delay(50);
}

// RTC EEPROM 全領域に同じ値を書き込む
boolean writeAll(uint8_t val) {
  uint8_t buff[8];
  for (int i = 0; i < 8; i++) buff[i] = val;
  for (int page = 0; page < 64; page++) {
    if (!RTC.writeEEPROMPage(page, buff)) {
      Serial.println();
      Serial.println("EEPROM write error.");
      return false;
    }
  }
  return true;
}

// RTC EEPROM 全領域を読取り表示
boolean readAll() {
  uint8_t buff[8];
  for (int page = 0; page < 64; page++) {
    if (!RTC.readEEPROMPage(page, buff)) {
      Serial.println();
      Serial.println("EEPROM read error.");
      return false;
    }
    if (page % 2 == 0) {
      print2hex(page * 8 / 16);
      Serial.print("0 :");
    }
    for (int i = 0 ; i < 8 ; i++) {
      Serial.write(' ');
      print2hex(buff[i]);
    }
    if (page % 2 != 0) {
      Serial.println();
    }
  }
  return true;
}

// 2桁16進表示
void print2hex(uint8_t number) {
  if (number < 16) {
    Serial.write('0');
  }
  Serial.print(number, 16);
}
