// HTTP クライアント動作のサンプルスケッチ
// SW3ボタンを押すとHTTP取得します
// Wi-Fiアクセスポイント環境に合わせて次のSSIDとパスワードを変更

#include <BiZduino.h>
#include <BiZduinoWiFi.h>

#define SSID        "<SSID>"
#define PASSWORD    "<PASSWORD>"
#define HOST_NAME   "dl.bizright.jp"
#define HOST_PORT   80
#define PATH        "/bd/sample1"


BiZduinoWiFi wifi;  // WiFiインスタンス
BiZduinoLED3 LED3;  // LED3インスタンス
BiZduinoSW3 SW3;    // SW3インスタンス

void setup() {
  // WiFi開始
  wifi.begin();

  // WiFiモジュールのファームバージョン取得
  String ver = wifi.getVersion();

  // Stationモードにする
  if (!wifi.setOprToStation()) {
    wifi.disableSerial();
    Serial.print("to station err\r\n");
  }

  // APに接続する
  if (!wifi.joinAP(SSID, PASSWORD)) {
    wifi.disableSerial();
    Serial.print("Join AP failure\r\n");
  }

  // マルチコネクションモードにする
  if (!wifi.enableMUX()) {
    wifi.disableSerial();
    Serial.print("multiple err\r\n");
  }

  // ローカルアドレスリスト取得
  String addr = wifi.getLocalIP();

  wifi.disableSerial();
  Serial.print("\r\n\n");

  // ファームバージョン表示
  Serial.print("FW Version: ");
  Serial.println(ver.c_str());

  // ローカルアドレスリスト表示
  Serial.print("Address: ");
  Serial.println(addr.c_str());

  Serial.print("setup end\r\n");

}

void loop() {
  static uint8_t mux_id = 0;
  uint8_t buffer[256] = {0};

  // SW3が押されたか判定
  if (SW3.isClicked()) {

    // LED3点灯
    LED3.on();

    // TCP接続
    if (wifi.createTCP(mux_id, HOST_NAME, HOST_PORT)) {

      // HTTPリクエスト送信
      char *req = "GET " PATH " HTTP/1.1\r\nHost: " HOST_NAME "\r\nUser-Agent: arduino\r\n\r\n";
      wifi.send(mux_id, (const uint8_t*)req, strlen(req));

      // HTTPレスポンス受信
      uint32_t len = wifi.recv(mux_id, buffer, sizeof(buffer), 10000);

      // TCP切断
      wifi.releaseTCP(mux_id);

      wifi.disableSerial();
      Serial.print("Data Receive ");
      Serial.print(mux_id);
      Serial.println(" ok");
      Serial.print("data length=");
      Serial.print(len);
      Serial.println("");
      if (len > 0) {
        Serial.print("Received:[");
        for (uint32_t i = 0; i < len; i++) {
          Serial.print((char)buffer[i]);
        }
        Serial.print("]\r\n");
      }
    } else {
      wifi.disableSerial();
      Serial.print("create tcp ");
      Serial.print(mux_id);
      Serial.println(" err");
    }

    // マルチリンクID変更
    mux_id++;
    if (mux_id >= 5) {
      mux_id = 0;
    }

    // LED3消灯
    LED3.off();
  }
}

