// HTTP サーバー動作のサンプルスケッチ
// 次の Wi-Fi に接続して、Webブラウザでアクセスすると「Hello world」が表示される

#include <BiZduino.h>
#include <BiZduinoWiFi.h>

#define SSID        "<SSID>"
#define PASSWORD    "<PASSWORD>"

#define HTTP_PORT   80


BiZduinoWiFi wifi;  // WiFiインスタンス
BiZduinoLED3 LED3;  // LED3インスタンス

void setup() {
  // WiFi開始
  wifi.begin();

  // Stationモードにする
  if (!wifi.setOprToStation()) {
    wifi.disableSerial();
    Serial.print("to station err\r\n");
  }

  // APに接続する
  if (!wifi.joinAP(SSID, PASSWORD)) {
    wifi.disableSerial();
    Serial.print("Join AP failure\r\n");
  }

  // マルチコネクションモードにする
  if (!wifi.enableMUX()) {
    wifi.disableSerial();
    Serial.print("multiple err\r\n");
  }

  // TCPサーバ開始
  if (!wifi.startTCPServer(HTTP_PORT)) {
    wifi.disableSerial();
    Serial.print("start tcp server err\r\n");
  }

  // TCPサーバタイムアウト設定
  if (!wifi.setTCPServerTimeout(10)) {
    wifi.disableSerial();
    Serial.print("set tcp server timout err\r\n");
  }

  // ローカルIPアドレスを求める
  // (CIFSR戻り値から「STAIP,"(IP addr)"」の部分を抜き出す
  String ip = "?";
  String list = wifi.getLocalIP();
  int32_t index1 = list.indexOf(F("STAIP,\""));
  if (index1 != -1) index1 += 7;
  int32_t index2 = list.indexOf(F("\""), index1);
  if (index1 != -1 && index2 != -1) {
    ip = list.substring(index1, index2);
  }

  wifi.disableSerial();
  Serial.print("\r\n\n\n");
  Serial.print("setup ok.\r\n");
  Serial.print("URL : http://");
  Serial.print(ip.c_str());
  Serial.print("/\r\n");

  wifi.enableSerial();
}

void loop() {
  char *header = "HTTP/1.1 200 OK\r\nContent-Type: text/html\r\n\r\n";
  char *content = "<html><head></head><body><h1>Hello world</h1></body></html>";
  char *notfound = "HTTP/1.1 404 Not Found\r\n\r\nNot Found!!";

  uint8_t buffer[128] = {0};
  uint8_t mux_id;

  // リクエスト受信待ち
  uint32_t len = wifi.recv(&mux_id, buffer, sizeof(buffer), 100);
  if (len > 0) {
    // LED3点灯
    LED3.on();

    if (strncmp(buffer, "GET / ", 6) == 0) { // GET / のみ応答

      // ヘッダ送信
      wifi.send(mux_id, header, strlen(header));

      // コンテンツ送信
      wifi.send(mux_id, content, strlen(content));

    } else {

      // Not Found 送信
      wifi.send(mux_id, notfound, strlen(notfound));

    }

    // TCPコネクション切断
    wifi.releaseTCP(mux_id);

    // LED3消灯
    LED3.off();
  }
}

