// RTCに時刻を設定するサンプルスケッチ

#include <BiZduinoRTC.h>

// 曜日文字列
const char *weekName[7] = {
  "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"
};
// 月文字列
const char *monthName[12] = {
  "Jan", "Feb", "Mar", "Apr", "May", "Jun",
  "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
};

DateTime dt;

void setup() {
  // シリアルモニタとの通信を開始
  Serial.begin(115200);
  RTC.begin();

  Serial.print("configured Date=");
  Serial.print(__DATE__);
  Serial.print(", Time=");
  Serial.println(__TIME__);

  // コンパイル日時を時刻に変換
  getDateTime(__DATE__, __TIME__);

  ////////////////////////////////////////////////////////
  // RTC設定

  Serial.println("RTC.adjust()");

  if (RTC.adjust(dt)) {
    // RTCの時刻を取得して表示
    printRTC();
  } else {
    // RTCエラー
    Serial.println("RTC set error!");
  }
}

void loop() {
}


// RTCの時刻を取得して表示
void printRTC() {

  // RTCの時刻を取得
  if (RTC.read(dt)) {

    Serial.print(dt.year());    // 年の表示
    Serial.write('/');
    print2digits(dt.month());   // 月の表示
    Serial.write('/');
    print2digits(dt.day());     // 日の表示
    Serial.write(' ');
    Serial.print(weekName[dt.dayOfWeek()]); // 曜日の表示
    Serial.write(' ');
    print2digits(dt.hour());    // 時の表示
    Serial.write(':');
    print2digits(dt.minute());  // 分の表示
    Serial.write(':');
    print2digits(dt.second());  // 秒の表示
    Serial.println();
  } else {
    Serial.println("RTC read error!");
  }
}

// 2桁表示
void print2digits(int number) {
  if (number >= 0 && number < 10) {
    Serial.write('0');
  }
  Serial.print(number);
}

// 日付文字列と時刻文字列から年月日時分秒に変換
bool getDateTime(const char *strDate, const char *strTime)
{
  char Month[12];
  int Day, Year;
  uint8_t monthIndex;
  int Hour, Min, Sec;
  if (sscanf(strDate, "%s %d %d", Month, &Day, &Year) != 3) {
    return false;
  }
  if (sscanf(strTime, "%d:%d:%d", &Hour, &Min, &Sec) != 3) {
    return false;
  }
  for (monthIndex = 0; monthIndex < 12; monthIndex++) {
    if (strcmp(Month, monthName[monthIndex]) == 0) break;
  }
  if (monthIndex >= 12) {
    return false;
  }
  dt = DateTime(Year, monthIndex + 1, Day, Hour, Min, Sec);
  return true;
}


